@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.9 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.9 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorCmd extends SyL_Error
@@ -53,6 +53,11 @@ class SyL_ErrorCmd extends SyL_Error
      */
     function displayError($error_messages, $error_trace)
     {
+        // display_errorsoffξϥ顼̤ɽʤ
+        if (!ini_get('display_errors')) {
+            return;
+        }
+
         // 顼å
         $error_message = implode($this->eof, $error_messages) . $this->eof;
         // 顼åɽ
