@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.15 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.16 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.15 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.16 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -55,6 +55,11 @@ class SyL_ErrorWeb extends SyL_Error
      */
     function displayError($error_messages, $error_trace)
     {
+        // display_errorsoffξϥ顼̤ɽʤ
+        if (!ini_get('display_errors')) {
+            return;
+        }
+
         // 顼å
         $error_message = implode('<br>', $error_messages);
 
@@ -152,20 +157,22 @@ class SyL_ErrorWeb extends SyL_Error
     function displayErrorTemplate($template_file, $_error_message, $_error_lines, $_error_trace, $view_type)
     {
         // ǡ饹
-        $this->dm->setViewParameter('viewtype', $view_type[1]);
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
+        $dm =& new SyL_DataManager($this->controller);
+        $dm->setViewParameter('viewtype', $view_type[1]);
         if ($view_type[0] == 'layout') {
-            $this->dm->setViewParameter('viewlayout', 'true');
+            $dm->setViewParameter('viewlayout', 'true');
         } else {
-            $this->dm->setViewParameter('viewlayout', 'false');
+            $dm->setViewParameter('viewlayout', 'false');
         }
-        $this->dm->setTemplateFile($template_file);
-        $this->dm->setParameter('_error_message', $_error_message);
-        $this->dm->setParameter('_error_lines',   $_error_lines);
-        $this->dm->setParameter('_error_trace',   $_error_trace);
+        $dm->setTemplateFile($template_file);
+        $dm->setParameter('_error_message', $_error_message);
+        $dm->setParameter('_error_lines',   $_error_lines);
+        $dm->setParameter('_error_trace',   $_error_trace);
 
         // ӥ塼饹
         include_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
-        $view =& SyL_View::getObject($this->dm);
+        $view =& SyL_View::getObject($dm);
         $view->render();
 
         $response =& SyL_Response::getInstance();
