@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterAuth.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterAuth.php,v 1.2 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterAuth.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterAuth.php,v 1.2 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FilterAuth extends SyL_Filter
@@ -118,21 +118,9 @@ class SyL_FilterAuth extends SyL_Filter
     function postAction(&$dm)
     {
         // ǧڥꥢȽ
-        if (is_bool($this->login)) {
-            if ($this->login) {
-                if (SYL_ENV_TYPE == 'web') {
-                    // TOPإ쥯
-                    $this->auth->redirect();
-                } else {
-                    $dm->setParameter('_auth_url', $this->auth->getRedirectUrl());
-                }
-            }
-
-            if (SYL_ENV_TYPE == 'js') {
-                // 󥢥󤬤ϡJSONӥ塼ѹ
-                $dm->setViewParameter('viewtype', 'json');
-            }
-            $dm->setParameter('_auth_login', $this->login);
+        if (is_bool($this->login) && $this->login) {
+            // TOPإ쥯
+            $dm->setRedirectUrl(SyL_Auth::getRedirectUrl());
         }
     }
 }
