@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.12 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -67,7 +67,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Router.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.12 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterParameter extends SyL_Router
@@ -78,15 +78,17 @@ class SyL_RouterParameter extends SyL_Router
      * @access private
      * @var string
      */
-    var $action_delimiter = SYL_ROUTER_ACTION_DELIMITER;
+    var $action_delimiter = '.';
 
     /**
-     * 󥹥ȥ饯
+     * ܾ󥪥֥ȤΥץѥƥ
      *
-     * @access public
+     * @access protected
+     * @param object ꥯȥ֥
      */
-    function SyL_RouterParameter($pathinfo)
+    function createProperty(&$request)
     {
+        $pathinfo = $request->getParameter(SYL_ACTION_KEY);
         // ѥå
         if ($this->isInvalidPath($pathinfo)) {
             SyL_Response::redirect404();
