@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.12 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,40 +42,47 @@
  * ƥץ졼ȥե̾
  *
  * +++ 
- *   /dir/app1.php/hoge1/hoge2/cmd.html
+ *   /dir/app1.php/hoge1/hoge2/cmd.test.html
  * 
  * [ե̾]
- *   /hoge1/hoge2/app1.php
- *   1) .../app1.php/test2_2/test.html => /test2_2/app1.php
- *   2) .../app1.php/test.html => /app1.php
+ *   /hoge1/hoge2/test.php
+ *   1) .../app1.php/test2_2/test.html => /test2_2/test.php
+ *   2) .../app1.php/test.html => /test.php
  *   3) .../app1.php/ => /ʥǥեȥ̾
  * [󥯥饹̾]
- *   Hoge1_Hoge2_App1
+ *   Hoge1_Hoge2_Test
  * [̾]
  *   cmd
- *   1) .../app1.php/test2_2/cmd => cmd
+ *   1) .../app1.php/test2_2/test.html => ̵
  *   2) .../app1.php/ => ̵
  * [ƥץ졼ȥե̾]
- *   /hoge1/hoge2/app1.html
+ *   /hoge1/hoge2/test.html
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.12 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
 {
     /**
-     * 󥹥ȥ饯
+     * ζڤʸ
      *
-     * @access public
+     * @access private
+     * @var string
      */
-    function SyL_RouterPathinfo($action)
+    var $action_delimiter = '.';
+
+    /**
+     * ܾ󥪥֥ȤΥץѥƥ
+     *
+     * @access protected
+     * @param object ꥯȥ֥
+     */
+    function createProperty(&$request)
     {
-        // ١ץȼ
-        $script_name = basename($_SERVER['SCRIPT_NAME']);
         // PATH_INFOĶѿ
         $pathinfo = isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : '';
 
@@ -86,35 +93,59 @@ class SyL_RouterPathinfo extends SyL_Router
 
         if ($pathinfo == '') {
             $this->action_name = '';
-            $this->action_file = '/' . $script_name;
+            $this->action_file = '/' . $this->action_file_default;
         } else if (substr($pathinfo, -1) == '/') {
             $this->action_name = '';
-            $this->action_file = $pathinfo . $script_name;
+            $this->action_file = $pathinfo . $this->action_file_default;
         } else {
-            $pathinfo_dir = dirname($pathinfo);
+            // ĥȽ
+            if ($this->ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
+                SyL_Response::redirect404();
+            }
+            $pathinfo_file  = basename($pathinfo);
+            $pathinfo_dir   = dirname($pathinfo);
+            $pathinfo_files = explode($this->action_delimiter, $pathinfo_file, 2);
+
             // windowsб
             if ($pathinfo_dir == '\\') {
-                $pathinfo_dir = '/';
+                $pathinfo_dir = '';
             }
-            if ($pathinfo_dir == '/') {
-                $this->action_file = '/' . $script_name;
-            } else {
-                $this->action_file = $pathinfo_dir . '/' . $script_name;
+
+            if ($pathinfo_dir != '/') {
+                $pathinfo_dir = $pathinfo_dir . '/';
             }
-            if ($this->ext) {
-                if (preg_match( '/^(.*)\/(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo, $matches)) {
-                    $this->action_name = $matches[2];
+
+            if (count($pathinfo_files) == 2) {
+                if (($this->action_delimiter == '.') && ($this->url_ext == ('.' . $pathinfo_files[1]))) {
+                    // ʤ
+                    $this->action_name = '';
+                    $this->action_file = $pathinfo_dir . $pathinfo_files[0] . $this->exe_ext;
                 } else {
-                    SyL_Response::redirect404();
+                    if (preg_match('/^(.+)(' . preg_quote($this->url_ext) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
+                        // 󤢤
+                        $this->action_name = $pathinfo_files[0];
+                        $this->action_file = $pathinfo_dir . $matches[1] . $this->exe_ext;
+                    } else {
+                        // 󤢤
+                        $this->action_name = $pathinfo_files[0];
+                        $this->action_file = $pathinfo_dir . $pathinfo_files[1] . $this->exe_ext;
+                    }
                 }
             } else {
-                $this->action_name = basename($pathinfo);
+                // ʤ
+                $this->action_name = '';
+                if (preg_match('/^(.+)(' . preg_quote($this->url_ext) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
+                    $this->action_file = $pathinfo_dir . $matches[1] . $this->exe_ext;
+                } else {
+                    $this->action_file = $pathinfo_dir . $pathinfo_files[1] . $this->exe_ext;
+                }
             }
         }
 
         // ֤
-        if ($action !== null) {
-            $this->action_name = $action;
+        $action_name = $request->getParameter(SYL_ACTION_KEY);
+        if ($action_name !== null) {
+            $this->action_name = $action_name;
         }
 
         // PATH_INFO
@@ -126,28 +157,26 @@ class SyL_RouterPathinfo extends SyL_Router
 
         // 饹ե
         if ($this->action_file != '') {
-            $classname = implode( '_', array_map('ucfirst', $this->pathinfo) );
+            $classname = implode('_', array_map('ucfirst', $this->pathinfo));
             if ($classname != '') {
-                $classname = $classname . '_' . ucfirst(basename($script_name,$this->exe_ext));
+                $this->class_name = $classname . '_' . ucfirst(basename($this->action_file, $this->exe_ext));
             } else {
-                $classname = ucfirst(basename($script_name,$this->exe_ext));
+                $this->class_name = ucfirst(basename($this->action_file, $this->exe_ext));
             }
-            $this->class_name = $classname;
         }
 
 /*
-echo "script_name: " . $script_name . "<br>";
 echo "pathinfo: " . $pathinfo . "<br>";
 echo "action_name: " . $this->action_name . "<br>";
 echo "action_file: " . $this->action_file . "<br>";
 echo "class_name: " . $this->class_name . "<br>";
+echo "syl_self: " . $this->syl_self . "<br>";
 echo "<pre>";
 print_r($this->pathinfo);
 echo "</pre>";
 exit;
 */
 
-
     }
 
 }
