@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.15 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.16 2007/03/31 08:45:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.15 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.16 2007/03/31 08:45:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -296,11 +296,23 @@ echo "</pre>";
                 case 'setter':
                     $component =& $this->getComponent($name);
                     if ($funcs[2] === 'true') {
-                        foreach ($value_args as $key => $value) {
-                            $component->$funcs[1] =& $value_args[$key];
+                        if (array_key_exists($funcs[1], get_object_vars($component))) {
+                            foreach ($value_args as $key => $value) {
+                                if ($keys['reference']) {
+                                    $component->$funcs[1] =& $value_args[$key];
+                                } else {
+                                    $component->$funcs[1] = $value_args[$key];
+                                }
+                            }
+                        } else {
+                            $this->log('info', "Setter injection failed: setter not found (" . get_class($component) . ".{$funcs[1]})");
                         }
                     } else {
-                        call_user_func_array(array(&$component, $funcs[1]), $value_args);
+                        if (method_exists($component, $funcs[1])) {
+                            call_user_func_array(array(&$component, $funcs[1]), $value_args);
+                        } else {
+                            $this->log('info', "Setter injection failed: setter not found (" . get_class($component) . ".{$funcs[1]})");
+                        }
                     }
                     break;
                 }
