@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.19 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.20 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.19 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.20 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -58,13 +58,6 @@ class SyL_Error
      * @var string
      */
     var $eof = "\r\n";
-    /**
-     * ǡ֥
-     * 
-     * @access protected
-     * @var object
-     */
-    var $dm = null;
     /**
      * ȥ
      * 
@@ -99,10 +92,10 @@ class SyL_Error
     {
         static $singleton;
         if (!is_object($singleton)) {
-            $class_name = 'SyL_Error' . ucfirst(SYL_ENV_TYPE);
-            include_once SYL_INCLUDE_DIR . "/framework/Error/{$class_name}.php";
+            $classname = 'SyL_Error' . ucfirst(SYL_ENV_TYPE);
+            include_once SYL_INCLUDE_DIR . "/framework/Error/{$classname}.php";
             // ҥ饹Υ󥹥
-            $singleton = new $class_name();
+            $singleton = new $classname();
         }
         return $singleton;
     }
@@ -118,18 +111,6 @@ class SyL_Error
         $this->controller =& $controller;
     }
 
-    /**
-     * ǡ֥Ȥ򥻥å
-     *
-     * @access public
-     * @param object ǡ֥
-     */
-    function setDataManager(&$dm)
-    {
-        $this->dm =& $dm;
-        $this->setController($this->dm->controller);
-    }
-
     /**
      * 顼ϥɥ
      * 
@@ -398,6 +379,10 @@ class SyL_Error
                 $server = isset($_SERVER['SERVER_NAME']) ? $_SERVER['SERVER_NAME'] : '';
             }
 
+            $request_uri = isset($_SERVER['REQUEST_URI'])     ? $_SERVER['REQUEST_URI']     : '';
+            $user_agent  = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '';
+            $server_software = isset($_SERVER['SERVER_SOFTWARE']) ? $_SERVER['SERVER_SOFTWARE'] : '';
+
             // ȥ졼դ顼å
             $error_message  = $this->getErrorMessageTrace();
             // SyLΥС
@@ -409,14 +394,17 @@ class SyL_Error
             $error_mail_body = <<< EOF
 SyL Framework Error info.
 ----------------------------------------
-Date: {$date}
-Server: {$server}
+DATE: {$date}
+SERVER: {$server}
+REQUEST_URI: {$request_uri}
+HTTP_USER_AGENT: {$user_agent}
 
 {$error_message}
 
 ----------------------------------------
+SyL Framework ver. {$version} on PHP {$version_php}
+{$server_software}
 {$uname}
-PHP {$version_php} on SyL ver. {$version}
 EOF;
 
             // 顼᡼¹
