@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Request
@@ -117,8 +117,9 @@ class SyL_Request
      function createParameter()
      {
          if ($this->parameter == null) {
-             include_once SYL_INCLUDE_DIR . '/framework/RequestParameter/SyL_RequestParameterDefault.php';
-             $this->parameter =& new SyL_RequestParameterDefault();
+             $classname = 'SyL_RequestParameter' . ucfirst(SYL_ENV_TYPE);
+             include_once SYL_INCLUDE_DIR . "/framework/RequestParameter/{$classname}.php";
+             $this->parameter =& new $classname();
          }
      }
 
