@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.17 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.18 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.17 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.18 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -117,50 +117,66 @@ class SyL_View
     {
         $view = null;
         $type = $dm->getViewParameter('viewtype');
-        $class_name = '';
-        $class_file = '';
-        if ($dm->getViewParameter('viewlayout') === 'true') {
-            // Layout 饹
-            switch ($type) {
-            case 'smarty' :
-            case 'default':
-                $class_name = 'SyL_ViewLayout' . ucfirst($type);
-                break;
-            default:
-                trigger_error("[SyL error] Layout type not found ({$type})", E_USER_ERROR);
-            }
-            $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
-            include_once $class_file;
-            $view =& new $class_name($dm);
-            $view->parseConfig($dm->controller);
-        } else {
-            switch ($type) {
-            case 'customize':
-                $class_name = $dm->getViewParameter('customizedviewclass');
-                $class_file = $dm->getViewParameter('customizedviewfile');
-                if (!is_file($class_file)) {
-                    $class_file1 = SYL_WEBAPP_LIB_DIR . "/{$class_file}";
-                    if (!is_file($class_file1)) {
-                        trigger_error("[SyL error] Customised View file not found ({$class_file} or {$class_file1})", E_USER_ERROR);
-                    }
-                    $class_file = $class_file1;
-                }
-                break;
-            case 'js.ajax':
-            case 'js.login':
-                $class_name = 'SyL_View' . implode('', array_map('ucfirst', explode('.', $type)));
-                $class_file = SYL_INCLUDE_DIR . "/framework/View/Js/{$class_name}.php";
-                break;
-            default:
-                $class_name = 'SyL_View' . ucfirst($type);
-                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
-                if (!is_file($class_file)) {
-                    trigger_error("[SyL error] Customised View file not found ({$class_file} or {$class_file1})", E_USER_ERROR);
-                }
-            }
 
-            include_once $class_file;
-            $view =& new $class_name($dm);
+        switch (SYL_ENV_TYPE) {
+        case 'web':
+            if ($dm->getViewParameter('viewlayout') === 'true') {
+                switch ($type) {
+                case 'smarty' :
+                case 'default':
+                    $classname = 'SyL_ViewLayout' . ucfirst($type);
+                    break;
+                default:
+                    trigger_error("[SyL error] Layout type not found ({$type})", E_USER_ERROR);
+                }
+                $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
+                include_once $classfile;
+                $view =& new $classname($dm);
+                $view->parseConfig($dm->controller);
+            } else {
+                if ($type == 'customize') {
+                    $classname = $dm->getViewParameter('customizedviewclass');
+                    $classfile = $dm->getViewParameter('customizedviewfile');
+                    if (!is_file($classfile)) {
+                        $classfile1 = SYL_WEBAPP_LIB_DIR . "/{$classfile}";
+                        if (!is_file($classfile1)) {
+                            trigger_error("[SyL error] Customised View file not found ({$classfile} or {$classfile1})", E_USER_ERROR);
+                        }
+                        $classfile = $classfile1;
+                    }
+                } else {
+                    $classname = 'SyL_View' . ucfirst($type);
+                    $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
+                    if (!is_file($classfile)) {
+                        trigger_error("[SyL error] Web View file not found ({$classfile})", E_USER_ERROR);
+                    }
+                }
+                include_once $classfile;
+                $view =& new $classname($dm);
+            }
+            break;
+
+        case 'js':
+            if (strpos($type, '.') !== false) {
+                $classname = 'SyL_View' . implode('', array_map('ucfirst', explode('.', $type)));
+                $classfile = SYL_INCLUDE_DIR . "/framework/View/Js/{$classname}.php";
+            } else {
+                $classname = 'SyL_View' . ucfirst($type);
+                $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
+            }
+            if (!is_file($classfile)) {
+                trigger_error("[SyL error] Js View file not found ({$classfile})", E_USER_ERROR);
+            }
+            include_once $classfile;
+            $view =& new $classname($dm);
+            break;
+
+        case 'xmlrpc':
+            $classname = 'SyL_ViewXmlrpc';
+            $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
+            include_once $classfile;
+            $view =& new $classname($dm);
+            break;
         }
 
         return $view;
@@ -173,9 +189,6 @@ class SyL_View
      */
     function parseConfig(&$controller)
     {
-        // եɤ߹९饹
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
-
         $config_file = SYL_APP_DIR . "/{$this->layout_file_name}";
         $reader =& SyL_Config::getObject('layouts', $config_file, $controller);
         $reader->parseXml();
