@@ -27,11 +27,16 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.4 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.5 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+/**
+ * JavaScriptϥ饹
+ */
+require_once SYL_INCLUDE_DIR . '/framework/SyL_Js.php';
+
 /**
  * JavaScriptӥ塼饹
  *
@@ -39,11 +44,19 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.4 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.5 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJs extends SyL_View
 {
+    /**
+     * Jsϥ֥
+     * 
+     * @access protected
+     * @var object
+     */
+    var $js = null;
+
     /**
      * 󥹥ȥ饯
      *
@@ -54,23 +67,30 @@ class SyL_ViewJs extends SyL_View
         parent::SyL_View($dm);
         // ƥĥפ򥻥å
         $this->setContentType('application/x-javascript; charset=' . SYL_ENCODE_INTERNAL);
+        $this->js =& new SyL_Js();
     }
 
     /**
-     * HTML󥰼¹
+     * JavaScript򥤥ݡȤ
+     * 
+     * @access public
+     */
+    function importJs()
+    {
+        $request =& SyL_Request::getInstance();
+        $this->js->import($request->getParameter('import'));
+    }
+
+    /**
+     * JavaScript󥰼¹
      * 
      * @access public
      */
     function render()
     {
-        $request =& SyL_Request::getInstance();
-
-        include_once SYL_INCLUDE_DIR . '/lib/SyL_Js.php';
-        $js =& new SyL_Js();
-        $js->setImport($request->getParameter('import'));
-
+        $this->importJs();
         // JavaScirpt
-        $this->setRender($js->getJs());
+        $this->setRender($this->js->getJs());
     }
 }
 
