@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBIbase.php,v 1.2 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBIbase.php,v 1.3 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,13 +35,11 @@
 /**
  *  DB饹Intrebase, Firebird
  *
- * ڡ᥽åɤѤʤ顢Firebird 2.0 ʾ
- *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBIbase.php,v 1.2 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBIbase.php,v 1.3 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBIbase extends SyL_DB
@@ -391,6 +389,24 @@ class SyL_DBIbase extends SyL_DB
         $this->queryRef($sql, $data, 'one');
         return $data;
     }
+
+    /**
+     * ³ƤDBСΥС
+     * 
+     * @access public
+     * @return string DBΥС
+     */
+    function getVersion()
+    {
+/*
+        $sql = "SHOW VERSION";
+        $this->queryRef($sql, $version, 'one');
+        list($version) = explode('-', $version);
+        
+        return $version;
+*/
+        return false;
+    }
 }
 
 ?>
