@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBPdofirebird.php,v 1.2 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBPdofirebird.php,v 1.3 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_DBPdo.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBPdofirebird.php,v 1.2 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBPdofirebird.php,v 1.3 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBPdofirebird extends SyL_DBPdo
@@ -183,6 +183,23 @@ class SyL_DBPdofirebird extends SyL_DBPdo
         return $this->queryRef($sql_page, $result, 'all');
     }
 
+    /**
+     * ³ƤDBСΥС
+     * 
+     * @access public
+     * @return string DBΥС
+     */
+    public function getVersion()
+    {
+/*
+        $sql = "SHOW VERSION";
+        $this->queryRef($sql, $version, 'one');
+        list($version) = explode('-', $version);
+        
+        return $version;
+*/
+        return false;
+    }
 }
 
 ?>
