@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementFile.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementFile.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,54 +35,43 @@
 /**
  * եϥեǥ饹
  *
- * ̾ : ̾ : ̾(name) : (value)
- *   1  :      -     :    1         :   1
- *
- * 󥹥󥹺ˡ
- * // 쥯饹饹ƥå᥽åɤǼ
- * $element = SyL_FormElement::create( 'text', 'name', '̾' );
- *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementFile.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementFile.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FormElementFile extends SyL_FormElement
 {
     /**
-     * 󥹥ȥ饯
+     * Ǵ֤ζڤʸ
+     *
+     * @access private
+     * @var string
+     */
+    var $separator = "&nbsp;/&nbsp;";
+
+    /**
+     * ̾ʣˤ
      *
      * @access public
-     * @param string եHTML̾
-     * @param string եɽ̾
-     * @param string եǤ
-     * @param array եǤradio, select, checkboxξΤߡ
-     * @param string եǤɲ°
+     * @return string ̾
      */
-    function SyL_FormElementFile($name, $display_name, $options=array(), $value=null, $attributes=array())
+    function getNames()
     {
-        $this->type         = 'file';
-        $this->name         = $name;
-        $this->display_name = $display_name;
-        // ǥեͤμ
-        $this->value     = ($value === null) ? $this->getParameter() : $value;
-        $this->attributes = array_merge($this->attributes, $attributes);
+        return $this->getName() . '[]';
     }
 
     /**
-     * ꥯȤͤ
-     * С饤
+     * ͤ򥻥åȤ
      *
      * @access public
-     * @param string եHTML̾
-     * @return mixed ꥯѿ
+     * @param mixed 
      */
-    function getParameter($name)
+    function setValue($value)
     {
-        $value = isset($_FILES[$name]) ? $_FILES[$name] : '';
-        return $value;
+        $this->value = isset($_FILES[$this->name]) ? $_FILES[$this->name] : null;
     }
 
     /**
@@ -93,15 +82,10 @@ class SyL_FormElementFile extends SyL_FormElement
      */
     function getHtmlTag()
     {
-        $html_element  = '';
-        $html_element .= '<input ';
-        $html_element .=   'type="'  . $this->type      . '" ';
-        $html_element .=   'name="'  . $this->name . '[]" ';
-        $html_element .=   'value="" ';
-        $html_element .= $this->getAttribute();
-        $html_element .= '>';
+        $this->setAttribute($this->getNames(), 'name');
+        $this->setAttribute($this->type, 'type');
 
-        return $html_element;
+        return '<input ' . $this->getAttributes() . ' />';
     }
 
     /**
@@ -112,24 +96,27 @@ class SyL_FormElementFile extends SyL_FormElement
      */
     function getHtmlView()
     {
-        return $this->encodeHtml(implode('/', $this->value['name']));
+        if (isset($this->value['name'])) {
+            return implode($this->separator, array_map(array(&$this, 'encode'), $this->value['name']));
+        } else {
+            return '&nbsp;';
+        }
     }
 
     /**
      * JavaScriptϥå
-     * С饤
      *
      * @access public
      * @return string JavaScriptϥå
      */
-    function getJavaScript()
+    function getJs()
     {
         if (is_object($this->validators)) {
             $js  = '';
-            $js .= 'var error_flag = false;' . "\r\n";
-            $js .= 'var element_name = "' . $this->getName() . '[]";' . "\r\n";
-            $js .= $this->validators->getJavaScript($this->getDisplayName(), $this->options);
-            $js .= "\r\n";
+            $js .= 'var error_flag = false;' . "\n";
+            $js .= 'var element_name = "' . $this->getNames() . '";' . "\n";
+            $js .= $this->validators->getJs($this->getDisplayName(), $this->options);
+            $js .= "\n";
             return $js;
         } else {
             return '';
@@ -137,5 +124,4 @@ class SyL_FormElementFile extends SyL_FormElement
     }
 }
 
-
 ?>
