@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementHidden.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementHidden.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -46,31 +46,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementHidden.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementHidden.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FormElementHidden extends SyL_FormElement
 {
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param string եHTML̾
-     * @param string եɽ̾
-     * @param string եǤ
-     * @param array եǤradio, select, checkboxξΤߡ
-     * @param string եǤɲ°
-     */
-    function SyL_FormElementHidden($name, $display_name, $options=array(), $value=null, $attributes=array())
-    {
-        $this->type         = 'hidden';
-        $this->name         = $name;
-        $this->display_name = $display_name;
-        // ǥեͤμ
-        $this->value     = ($value === null) ? $this->getParameter() : $value;
-        $this->attributes = array_merge($this->attributes, $attributes);
-    }
-
     /**
      * եHTMLϡϹܡ
      *
@@ -94,5 +74,4 @@ class SyL_FormElementHidden extends SyL_FormElement
     }
 }
 
-
 ?>
