@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementPassword.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementPassword.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,65 +35,31 @@
 /**
  * ѥɥեǥ饹
  *
- * ̾ : ̾ : ̾(name) : (value)
- *   1  :      -     :    1         :   1
- *
- * 󥹥󥹺ˡ
- * // 쥯饹饹ƥå᥽åɤǼ
- * $SyL_FormElementPassword = SyL_FormElement::createElement( 'password', 'passwd', 'ѥ' );
- *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementPassword.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementPassword.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FormElementPassword extends SyL_FormElement
 {
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param string եHTML̾
-     * @param string եɽ̾
-     * @param string եǤ
-     * @param array եǤradio, select, checkboxξΤߡ
-     * @param string եǤɲ°
-     */
-    function SyL_FormElementPassword($name, $display_name, $options=array(), $value=null, $attributes=array())
-    {
-        $this->type = 'password';
-        $this->name = $name;
-        $this->display_name = $display_name;
-        // ǥեͤμ
-        $this->value     = ($value === null) ? $this->getParameter() : $value;
-        $this->attributes = $attributes;
-    }
-
     /**
      * եHTML
-     * С饤
      *
      * @access public
-     * @param bool true: html󥳡ɤԤfalse: html󥳡ɤԤʤ
      * @return string եǤHTML
      */
-    function getHtmlTag( $html_encode=true )
+    function getHtmlTag()
     {
-        $html_element  = '';
-        $html_element .= '<input ';
-        $html_element .=   'type="'  . $this->type      . '" ';
-        $html_element .=   'name="'  . $this->name . '" ';
-        $html_element .= $this->getAttribute();
-        $html_element .= '>';
+        $this->setAttribute($this->name, 'name');
+        $this->setAttribute($this->type, 'type');
 
-        return $html_element;
+        return '<input ' . $this->getAttributes() . ' />';
     }
 
     /**
      * եHTML
-     * С饤
      *
      * @access public
      * @return string եǤHTML
