@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementText.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementText.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,42 +35,15 @@
 /**
  * ƥȥեǥ饹
  *
- * ̾ : ̾ : ̾(name) : (value)
- *   1  :      -     :    1         :   1
- *
- * 󥹥󥹺ˡ
- * // 쥯饹饹ƥå᥽åɤǼ
- * $SyL_FormElementText = SyL_FormElement::createElement( 'text', 'name', '̾' );
- *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementText.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementText.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FormElementText extends SyL_FormElement
 {
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param string եHTML̾
-     * @param string եɽ̾
-     * @param string եǤ
-     * @param array եǤradio, select, checkboxξΤߡ
-     * @param string եǤɲ°
-     */
-    function SyL_FormElementText($name, $display_name, $options=array(), $value=null, $attributes=array())
-    {
-        $this->type         = 'text';
-        $this->name         = $name;
-        $this->display_name = $display_name;
-        // ǥեͤμ
-        $this->value     = ($value === null) ? $this->getParameter() : $value;
-        $this->attributes = array_merge($this->attributes, $attributes);
-    }
-
     /**
      * եHTMLϡϹܡ
      *
@@ -79,15 +52,11 @@ class SyL_FormElementText extends SyL_FormElement
      */
     function getHtmlTag()
     {
-        $html_element  = '';
-        $html_element .= '<input ';
-        $html_element .=   'type="'  . $this->type      . '" ';
-        $html_element .=   'name="'  . $this->name . '" ';
-        $html_element .=   'value="' . $this->encodeHtml($this->value) . '" ';
-        $html_element .= $this->getAttribute();
-        $html_element .= '>';
+        $this->setAttribute($this->name, 'name');
+        $this->setAttribute($this->type, 'type');
+        $this->setAttribute($this->value, 'value');
 
-        return $html_element;
+        return '<input ' . $this->getAttributes() . ' />';
     }
 
     /**
@@ -98,7 +67,7 @@ class SyL_FormElementText extends SyL_FormElement
      */
     function getHtmlView()
     {
-        return $this->encodeHtml($this->value) . $this->getHtmlHidden();
+        return $this->encode($this->value) . $this->getHtmlHidden();
     }
 }
 
