@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailDefault.php,v 1.9 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailDefault.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailDefault.php,v 1.9 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailDefault.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_MailDefault extends SyL_Mail
@@ -47,26 +47,14 @@ class SyL_MailDefault extends SyL_Mail
     /**
      * 󥹥ȥ饯
      *
-     * @access private
+     * @access public
+     * @param string ѥ᡼
      */
-    function SyL_MailDefault()
+    function SyL_MailDefault($type)
     {
         parent::SyL_Mail();
     }
 
-    /**
-     * ᡼
-     *
-     * @access public
-     * @param array ᡼°
-     * @param bool ե饰
-     */
-    function init($attributes=array())
-    {
-        $attributes = array_change_key_case($attributes, CASE_LOWER);
-        parent::init($attributes);
-    }
-
     /**
      * ᡼¹
      *
@@ -76,25 +64,20 @@ class SyL_MailDefault extends SyL_Mail
     function send()
     {
         // Fromɬ
-        if ($this->headers['MAIL_FROM'] == '') {
+        if ($this->mail_property['MAIL_FROM'] == '') {
             $this->error_message = "[SyL error] From Address not found";
             return false;
         }
         // Toɬ
-        if (count($this->headers['To']) == 0) {
+        if (count($this->mail_property['RCPT_TO']) == 0) {
             $this->error_message = "[SyL error] To Address not found";
             return false;
         }
-
         // ꥿ѥΥå
-        if ($this->headers['MAIL_FROM'] != '') {
-            $additional_parameters = ' -f' . $this->headers['MAIL_FROM'];
-        } else {
-            $additional_parameters = null;
-        }
+        $additional_parameters = ' -f' . $this->mail_property['MAIL_FROM'];
 
         // ᡼¹
-        if (!mail(null, $this->headers['Subject'], null, $this->getHeaderMessage($this->body), $additional_parameters)) {
+        if (!mail(null, $this->headers['Subject'], null, $this->createSendMessage(), $additional_parameters)) {
             $this->error_message = "[SyL error] mail function execute error";
             return false;
         }
