@@ -27,18 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailSendmail.php,v 1.9 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailSendmail.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * sendmailޥ
- */
-if (!defined('SYL_MAIL_TYPE')) {
-    define('SYL_MAIL_TYPE', 'Sendmail:/usr/lib/sendmail');
-}
-
 /**
  *  Sendmail᡼饹
  *
@@ -46,7 +39,7 @@ if (!defined('SYL_MAIL_TYPE')) {
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailSendmail.php,v 1.9 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailSendmail.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_MailSendmail extends SyL_Mail
@@ -57,17 +50,19 @@ class SyL_MailSendmail extends SyL_Mail
      * @access private
      * @var string
      */
-    var $sendmail_path = '';
+    var $sendmail_path = '/usr/lib/sendmail';
 
     /**
      * 󥹥ȥ饯
      *
-     * @access private
+     * @access public
+     * @param string ѥ᡼
      */
-    function SyL_MailSendmail()
+    function SyL_MailSendmail($type)
     {
-        $tmp = explode(':', SYL_MAIL_TYPE, 2);
-        $this->sendmail_path = (strtolower($tmp[0]) == 'sendmail') ? $tmp[1] : $tmp[0];
+        if ($type) {
+            $this->setSendmailPath($type);
+        }
         parent::SyL_Mail();
     }
 
@@ -87,11 +82,9 @@ class SyL_MailSendmail extends SyL_Mail
      *
      * @access public
      * @param array ᡼°
-     * @param bool ե饰
      */
     function init($attributes=array())
     {
-        $attributes = array_change_key_case($attributes, CASE_LOWER);
         parent::init($attributes);
         // Sendmailѥ
         if (isset($attributes['sendmail'])) {
@@ -108,40 +101,25 @@ class SyL_MailSendmail extends SyL_Mail
     function send()
     {
         // Fromɬ
-        if ($this->headers['MAIL_FROM'] == '') {
+        if ($this->mail_property['MAIL_FROM'] == '') {
             $this->error_message = "[SyL error] From Address not found";
             return false;
         }
         // Toɬ
-        if (count($this->headers['To']) == 0) {
+        if (count($this->mail_property['RCPT_TO']) == 0) {
             $this->error_message = "[SyL error] To Address not found";
             return false;
         }
+        // ꥿ѥΥå
+        $additional_parameters = ' -f ' . $this->mail_property['MAIL_FROM'];
 
-        // Pathɬ
-        if ($this->sendmail_path == '') {
-            $this->error_message = "[SyL error] Sendmail path not found";
-            return false;
-        }
-
-        // ᡼إåޤʸ
-        $data = $this->getHeaderMessage($this->body);
-
-       // ꥿ѥΥå
-       if ($this->headers['MAIL_FROM'] != '') {
-           $additional_parameters = ' -f' . $this->headers['MAIL_FROM'];
-       } else {
-           $additional_parameters = '';
-       }
-
-        // ᡼¹ ----------------------------------------------------------
-
+        // ᡼¹
         $pmail = popen($this->sendmail_path . ' -t -i' . $additional_parameters, 'w');
         if (!$pmail) {
-            $this->error_message = "[SyL error] Sendmail command execute error";
+            $this->error_message = "[SyL error] Sendmail command execute error ({$this->sendmail_path})";
             return false;
         }
-        fputs($pmail, $data);
+        fputs($pmail, $this->createSendMessage());
         pclose($pmail);
 
         // 
