@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.12 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.13 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.12 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.13 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -473,7 +473,7 @@ class SyL_DB
      * @param int ɽоݥڡ 
      * @return bool ¹Է
      */
-    function queryPageRef($sql, &$result, &$page_control, $limit, $page=1) {}
+    function queryPageRef($sql, &$result, &$pager, $limit, $page=1) {}
 
     /**
      * ڡ󥰥֥Ȥ
@@ -515,11 +515,146 @@ class SyL_DB
      */
     function execBuilder(&$builder, $action='select')
     {
+        switch ($action) {
+        case 'select':
+        case 'insert':
+        case 'update':
+        case 'delete':
+            break;
+        default:
+            trigger_error("[SyL error] Invalid action ({$action})", E_USER_ERROR);
+        }
         $func = 'getStatement' . ucfirst($action);
         $sql  = call_user_func(array(&$builder, $func));
         return $this->exec($sql);
     }
 
+    /**
+     * SQLۥ饹SQL¹Ԥ
+     *
+     * @access public
+     * @param object SQLۥ֥
+     * @return mixed ¹Է
+     */
+    function queryBuilder(&$builder)
+    {
+        return $this->execBuilder($builder, 'select');
+    }
+
+    /**
+     * SQL¹Ԥڡ˥ǡ
+     *
+     * @access public
+     * @param object SQLۥ֥
+     * @param array ¹Է̳Ǽ
+     * @param object ڡ֥
+     * @param int 1ڡɽ
+     * @param int ɽоݥڡ 
+     * @return bool ¹Է
+     */
+    function queryBuilderPageRef(&$builder, &$result, &$pager, $limit, $page=1)
+    {
+        $sql = $builder->getStatementSelect();
+        return $this->queryPageRef($sql, $result, $pager, $limit, $page=1);
+    }
+
+    /**
+     * Υѥ᡼ˡSQLDMLˤȤΩƼ¹Ԥ
+     * ˥⼫ưǹԤ
+     * ѿǻꤹʳϡȽꤵ롣
+     *
+     * array(
+     *  'name'     => $name,
+     *  'address'  => $adress,
+     *  'datetime' => array('function' => 'current_timestamp'),
+     *  'id'       => array('number' => 1),
+     *  'IS_NULL'  => array('null' => ''),
+     *  ...
+     * );
+     *
+     * @access public
+     * @param string ơ֥̾
+     * @param array ȤΥǡ
+     * @param string insert or update or delete
+     * @param string ѥ᡼update, deleteΤߡ
+     * @return bool ¹Է true: OKfalse: 顼
+     */
+    function execPerform($table, $columns, $action='insert', $where='')
+    {
+        switch (strtolower($action)) {
+        case 'insert':
+            $field = array();
+            $data  = array();
+            foreach ($columns as $column => $value) {
+                $field[] = $column;
+                if (is_array($value)) {
+                    list($attribute, $value) = each($value);
+                    if ((strtolower($attribute) === 'null') || ($value === null) || ($value === '')) {
+                        $data[] = "NULL";
+                    } else {
+                        switch (strtolower($attribute)) {
+                        case 'function':
+                        case 'number':
+                            $data[] = $value;
+                            break;
+                        default:
+                            $data[] = $this->quote($value);
+                            break;
+                        }
+                    }
+                } else {
+                    $data[] = $this->quote($value);
+                }
+            }
+            // INSERT SQL
+            $sql = "INSERT INTO {$table} (" . implode(',', $field) . ") VALUES (" . implode(',', $data) . ")";
+            break;
+
+        case 'update':
+            $update = array();
+            foreach ($columns as $column => $value) {
+                if (is_array($value)) {
+                    list($attribute, $value) = each($value);
+                    if ((strtolower($attribute) === 'null') || ($value === null) || ($value === '')) {
+                        $update[] = $column . " = NULL";
+                    } else {
+                        switch (strtolower($attribute)) {
+                        case 'function':
+                        case 'number':
+                            $update[] = $column . " = " . $value;
+                            break;
+                        default:
+                            $update[] = $column . " = " . $this->quote($value);
+                            break;
+                        }
+                    }
+                } else {
+                    $update[] = $column . " = " . $this->quote($value);
+                }
+            }
+
+            if ($where) {
+                $where = "WHERE " . $where;
+            }
+            // UPDATE SQL
+            $sql = "UPDATE {$table} SET " . implode(',', $update) . " " . $where;
+            break;
+
+        case 'delete':
+            if ($where) {
+                $where = "WHERE " . $where;
+            }
+            // DELETE SQL
+            $sql = "DELETE FROM {$table} {$where}";
+            break;
+
+        default:
+          trigger_error("[SyL error] queryPerform method is insert or update or delete only", E_USER_ERROR);
+        }
+
+        return $this->exec($sql);
+    }
+
     /**
      * Ǹ줿Ԥ ID 뤤ϥ󥹤ͤ
      *
@@ -534,6 +669,17 @@ class SyL_DB
         return false;
     }
 
+    /**
+     * ³ƤDBСΥС
+     * 
+     * @access public
+     * @return string DBΥС
+     */
+    function getVersion()
+    {
+        return false;
+    }
+
     /**
      * ȥꥬ顼ưǵưʤ褦
      *
