@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.8 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.9 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.8 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.9 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_File
@@ -49,7 +49,7 @@ class SyL_File
      * 
      * @access public
      */
-    var $file_name;
+    var $filename;
     /**
      * ե륵
      * 
@@ -69,24 +69,39 @@ class SyL_File
      * @access public
      * @param string ե̾
      */
-    function SyL_File($file_name)
+    function SyL_File($filename)
     {
-        if (file_exists($file_name)) {
-            $this->file_size = filesize($file_name);
+        if (file_exists($filename)) {
+            $this->file_size = filesize($filename);
         }
-        $this->file_name = $file_name;
+        $this->filename = $filename;
+    }
+
+    /**
+     * SyL_File饹Υ󥹥󥹼
+     *
+     * @access public
+     * @param string ե
+     */
+    function &getObject($type, $filename)
+    {
+        $class_name = 'SyL_File' . ucfirst($type);
+        include_once dirname(__FILE__) . '/File/' . $class_name . '.php';
+        $file = new $class_name($filename);
+        return $file;
     }
 
     /**
      * ե򳫤
      *
      * @access public
+     * @param string ץ⡼
      */
-    function open( $mode )
+    function open($mode)
     {
-        $this->fp = fopen( $this->file_name, $mode );
+        $this->fp = fopen($this->filename, $mode);
         if (!is_resource($this->fp)) {
-            trigger_error( "[SyL error] File not found or Permission denied ({$this->file_name})", E_USER_ERROR );
+            trigger_error("[SyL error] File not found or Permission denied ({$this->filename})", E_USER_ERROR);
         } 
     }
 
