@@ -27,24 +27,19 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.8 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-// åȽ
-define( 'SYL_FORM_SESSION', false );
-// JS顼åǥեȥإå
-define( 'SYL_FORM_JS_ERROR_HEADER', 'ʲΥ顼ȯޤ\n\n' );
-// JS顼åǥեȥեå
-define( 'SYL_FORM_JS_ERROR_FOOTER', '' );
-// JSץ
-define( 'SYL_FORM_JS_SCRIPT', '/form/SyL_Validator.js' );
-
 /**
  * ڸ̥饹δ쥯饹
  */
 require_once 'SyL_FormElement.php';
+/**
+ * ڥ饹
+ */
+require_once 'SyL_Validation.php';
 
 /**
  * ե९饹
@@ -53,7 +48,7 @@ require_once 'SyL_FormElement.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.8 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Form
@@ -80,83 +75,66 @@ class SyL_Form
      */
     var $results = array();
     /**
-     * åǽȽ
-     *
-     * @access private
-     * @var bool
-     */
-    var $session = false;
-    /**
-     * JavaScriptϥåȽ
-     *
-     * @access private
-     * @var bool
-     */
-    var $js = false;
-    /**
+     * JavaScriptϥåȽ 
      * JavaScriptϥåؿ̾
      *
      * @access private
      * @var string
      */
-    var $js_func_name = 'SyLFormCheck';
+    var $js_func_name = '';
+    /**
+     * JavaScript顼åɽե饰
+     *
+     * @access private
+     * @var bool
+     */
+    var $js_all_message = true;
+    /**
+     * JavaScriptɽID
+     *
+     * @access private
+     * @var string
+     */
+    var $js_id = '';
     /**
      * JavaScript顼åΥإå
      *
      * @access private
      * @var string
      */
-    var $js_error_header = SYL_FORM_JS_ERROR_HEADER;
+    var $js_error_header = '';
     /**
      * JavaScript顼åΥեå
      *
      * @access private
      * @var string
      */
-    var $js_error_footer = SYL_FORM_JS_ERROR_FOOTER;
-    /**
-     * JavaScript饤֥URL
-     *
-     * @access private
-     * @var string
-     */
-    var $js_url = SYL_FORM_JS_SCRIPT;
+    var $js_error_footer = '';
 
     /**
      * 󥹥ȥ饯
      *
      * @access public
-     * @param string եHTML̾
-     * @param string եɽ̾ʥåܥåξΤ
-     * @param string եǤ
-     * @param array եǤradio, select, checkboxξΤߡ
-     * @param string եǤɲ°
+     * @param string ե̾
+     * @param string ꥯȥ᥽å
+     * @param string ꥯURL
      */
-    function SyL_Form($form_name="syl_form", $action=null, $method='post')
+    function SyL_Form($name="syl_form", $method='POST', $action=null)
     {
-        // å󤬻ѲǽȽ
-        if (SYL_FORM_SESSION) {
-            if (!session_id()) {
-                session_start();
-            }
-            if (isset($_SESSION['__SyL_Form__'])) {
-                $this->session = true;
-            } else {
-                $_SESSION['__SyL_Form__'] = true;
-            }
-        }
-
-        $this->attributes['name']   = $form_name;
-        $this->attributes['method'] = $method;
-        $this->attributes['action'] = ($action == null) ? $_SERVER["PHP_SELF"] : $action;
+        $this->setAttribute('name',   $name);
+        $this->setAttribute('id',     $name);
+        $this->setAttribute('method', strtoupper($method));
+        $this->setAttribute('action', !$action ? $_SERVER['PHP_SELF'] : $action);
 
         // եॹơ
-        $this->results['syl_form']       = '';
-        $this->results['syl_javascript'] = '';
-        $this->results['syl_read_only']  = false;
-        $this->results['syl_error']      = false;
+        $this->results['form']       = '';
+        $this->results['javascript'] = '';
+        $this->results['read_only']  = false;
+        $this->results['error']      = false;
         // 顼å
-        $this->results['syl_error_message'] = array();
+        $this->results['error_message'] = array();
+        // եǽ
+        $this->results['elements'] = array();
     }
 
     /**
@@ -164,32 +142,43 @@ class SyL_Form
      *
      * @access public
      * @param string եǥ
-     * @param string եHTML̾
+     * @param string ե̾
      * @param string եɽ̾
      * @param array եǤradio, select, checkboxξΤߡ
-     * @param mixed եǤ͡checkboxξ󡢤ʳstring
-     * @param string եǤɲ°
+     * @param array եǤɲ°
      */
-    function &createElement($type, $element_name, $display_name, $parts=array(), $value=null, $attributes=array())
+    function &createElement($type, $element_name, $display_name, $options=array(), $attributes=array())
     {
-        return SyL_FormElement::create($type, $element_name, $display_name, $parts, $value, $attributes);
+        $element =& SyL_FormElement::create($type, $element_name, $display_name, $this->getParameter($element_name), $options, $attributes);
+        if (is_a($element, 'SyL_FormElementGroup')) {
+            $element->initGroup($this);
+        }
+        return $element;
     }
 
     /**
-     * եǥ֥Ȥ򥻥å
+     * եǥ֥Ȥɲä
      *
      * @access public
      * @param object եǥ֥
      */
     function addElement(&$element)
     {
-        $name = $element->getName();
-        $element->setFormName($this->attributes['name']);
-        $element->setFormSession($this->session);
+        if ($element->getType() == 'file') {
+            $this->setAttribute('enctype', 'multipart/form-data');
+        } else if ($element->getType() == 'group') {
+            foreach ($element->elements as $element2) {
+                if ($element2->getType() == 'file') {
+                    $this->setAttribute('enctype', 'multipart/form-data');
+                    break;
+                }
+            }
+        }
+        $element_name = $element->getName();
         // ǥ֥ȳǼ
-        $this->elements[$name] =& $element;
+        $this->elements[$element_name] =& $element;
         // 
-        $this->results[$name] = array(
+        $this->results['elements'][$element_name] = array(
           'label'         => '',
           'html'          => '',
           'require'       => false,
@@ -197,54 +186,75 @@ class SyL_Form
           'error_message' => '',
           'read_only'     => false
         );
-      }
-
-    /**
-     * JavaScriptȽ
-     *
-     * @access public
-     * @param bool JavaScriptȽ
-     */
-    function setJavaScript( $js )
-    {
-        $this->js = $js;
-        $this->attributes['onSubmit'] = 'return ' . $this->js_func_name . '(this);';
     }
 
     /**
-     * JavaScript顼åإåեå
+     * եǥ֥Ȥ
      *
      * @access public
-     * @param string JavaScript顼åإå
-     * @param string JavaScript顼åեå
+     * @param string եHTML̾
+     * @return object եǥ֥
      */
-    function setJavaScriptHeaderFooter($js_header, $js_footer)
+    function &getElement($element_name)
     {
-        $this->js_error_header = $js_header;
-        $this->js_error_footer = $js_footer;
+        return $this->elements[$element_name];
     }
 
     /**
-     * ƤǤθڤ¹Ԥ
+     * ꥯȤͤ
      *
      * @access public
-     * @return true: 顼ʤfalse: 顼
+     * @param string ѥ᡼̾
+     * @return mixed ѥ᡼
      */
-    function validate()
+    function getParameter($name)
     {
-        $result = true;
-        foreach (array_keys($this->elements) as $key) {
-            if (!$this->elements[$key]->validate()) {
-                $name          = $this->elements[$key]->getName();
-                $error_message = $this->elements[$key]->getErrorMessage();
-                $this->results[$name]['error'] = true;
-                $this->results[$name]['error_message'] = $error_message;
-                $this->results['syl_error'] = true;
-                $this->results['syl_error_message'][] = $error_message;
-                $result = false;
-            }
+        switch ($this->getAttribute('method')) {
+        case 'POST': return isset($_POST[$name]) ? $_POST[$name] : null;
+        case 'GET':  return isset($_GET[$name])  ? $_GET[$name]  : null;
+        default:     return null;
         }
-        return $result;
+    }
+
+    /**
+     * եॿ°򥻥å
+     *
+     * @access public
+     * @param string եॿ°
+     * @param string եॿ°
+     */
+    function setAttribute($key, $value)
+    {
+        $key = strtolower($key);
+        $this->attributes[$key] = $value;
+    }
+
+    /**
+     * եॿ°򥻥å
+     *
+     * @access public
+     * @param string եॿ°
+     * @return string եॿ°
+     */
+    function getAttribute($key)
+    {
+        $key = strtolower($key);
+        return isset($this->attributes[$key]) ? $this->attributes[$key] : null;
+    }
+
+    /**
+     * եॿ°
+     *
+     * @access public
+     * @return string եॿ°
+     */
+    function getAttributes()
+    {
+        $attributes = array();
+        foreach ($this->attributes as $name => $value) {
+            $attributes[] = $name . '="' . $value . '"';
+        }
+        return implode(' ', $attributes);
     }
 
     /**
@@ -290,7 +300,7 @@ class SyL_Form
      * @access public
      * @return array ƤǤ
      */
-    function getValueAll()
+    function getValues()
     {
         $values = array();
         foreach (array_keys($this->elements) as $name) {
@@ -308,7 +318,7 @@ class SyL_Form
      */
     function isRequire($name)
     {
-        if ($this->results['syl_read_only']) {
+        if ($this->results['read_only']) {
             // ɽϡǤվ֤Ȥ
             return false;
         } else {
@@ -334,13 +344,38 @@ class SyL_Form
      * @access public
      * @param bool եǤɽΤߥե饰
      */
-    function readOnly($read_only)
+    function setReadOnly($read_only)
     {
-        foreach (array_keys($this->elements) as $key) {
-            $this->elements[$key]->readOnly($read_only);
+        if (!is_bool($read_only)) {
+            return;
         }
+        foreach (array_keys($this->elements) as $key) {
+            $this->elements[$key]->setReadOnly($read_only);
+        }
+        $this->results['read_only'] = $read_only;
+    }
 
-        $this->results['syl_read_only'] = $read_only;
+    /**
+     * ƤǤθڤ¹Ԥ
+     *
+     * @access public
+     * @return true: 顼ʤfalse: 顼
+     */
+    function validate()
+    {
+        $result = true;
+        foreach (array_keys($this->elements) as $key) {
+            if (!$this->elements[$key]->validate()) {
+                $name          = $this->elements[$key]->getName();
+                $error_message = $this->elements[$key]->getErrorMessage();
+                $this->results['elements'][$name]['error'] = true;
+                $this->results['elements'][$name]['error_message'] = $error_message;
+                $this->results['error'] = true;
+                $this->results['error_message'][] = $error_message;
+                $result = false;
+            }
+        }
+        return $result;
     }
 
     /**
@@ -352,15 +387,15 @@ class SyL_Form
      */
     function isError($name='')
     {
-        if ($name == '') {
-            foreach ($this->results as $name => $value) {
-                if ((substr($name, 0, 4) != 'syl_') && $value['error']) {
+        if ($name != '') {
+            return $this->results['elements'][$name]['error'];
+        } else {
+            foreach ($this->results['elements'] as $name => $value) {
+                if ($value['error']) {
                     return true;
                 }
           }
           return false;
-        } else {
-            return $this->results[$name]['error'];
         }
     }
 
@@ -373,10 +408,10 @@ class SyL_Form
      */
     function setErrorMessage($name, $error_message)
     {
-        $this->results[$name]['error'] = true;
-        $this->results[$name]['error_message'] = $error_message;
-        $this->results['syl_error'] = true;
-        $this->results['syl_error_message'][] = $error_message;
+        $this->results['elements'][$name]['error'] = true;
+        $this->results['elements'][$name]['error_message'] = $error_message;
+        $this->results['error'] = true;
+        $this->results['error_message'][] = $error_message;
     }
 
     /**
@@ -388,7 +423,7 @@ class SyL_Form
      */
     function getErrorMessage($name)
     {
-        return $this->results[$name]['error_message'];
+        return $this->results['elements'][$name]['error_message'];
     }
 
     /**
@@ -400,34 +435,34 @@ class SyL_Form
      */
     function getErrorMessageAll()
     {
-        return $this->results['syl_error_message'];
+        return $this->results['error_message'];
     }
 
     /**
-     * եॿ°򥻥å
+     * JavaScript
      *
      * @access public
-     * @param string եॿ°
-     * @param string եॿ°
+     * @param bool JavaScriptȽ
      */
-    function setAttribute($key, $value)
+    function useJs($js_func_name='syl_form_check', $js_all_message=true, $js_id='')
     {
-        $this->attributes[$key] = $value;
+        $this->js_func_name   = $js_func_name;
+        $this->js_all_message = $js_all_message;
+        $this->js_id          = $js_id;
+        $this->attributes['onSubmit'] = 'return ' . $this->js_func_name . '(this);';
     }
 
     /**
-     * եॿ°
+     * JavaScript顼åإåեå
      *
      * @access public
-     * @return string եॿ°
+     * @param string JavaScript顼åإå
+     * @param string JavaScript顼åեå
      */
-    function getAttributes()
+    function setJsHeaderFooter($js_header='', $js_footer='')
     {
-        $attributes = '';
-        foreach ($this->attributes as $name => $value) {
-            $attributes .= $name . '="' . $value . '" ';
-        }
-        return $attributes;
+        $this->js_error_header = $js_header;
+        $this->js_error_footer = $js_footer;
     }
 
     /**
@@ -436,48 +471,60 @@ class SyL_Form
      * @access public
      * @return string JavaScriptϥå
      */
-    function getJavaScript()
+    function getJs()
     {
-        static $js_include = false;
-        if (!$this->js) {
+        if (!$this->js_func_name) {
             return '';
         }
 
-        $js  = '';
-        if (!$js_include) {
-            $js  = '<script language="JavaScript" src="' . $this->js_url . '"></script>' . "\r\n";
-            $js_include = true;
-        }
-        $js .= '<script language="javascript">' . "\r\n";
-        $js .= '<!--' . "\r\n";
-        $js .= 'var ' . $this->js_func_name . '_submit = false;' . "\r\n";
-        $js .= 'function ' . $this->js_func_name . '(f)' . "\r\n";
-        $js .= '{' . "\r\n";
-        $js .= 'if (' . $this->js_func_name . '_submit) {' . "\r\n";
-        $js .= '  return false;' . "\r\n";
-        $js .= '}' . "\r\n";
-        $js .= 'var validator = new SyL_Validator(f);' . "\r\n";
-        $js .= "\r\n";
-        foreach (array_keys($this->elements) as $key) {
-            $js .= $this->elements[$key]->getJavaScript();
-        }
-        $js .= 'if (!' . $this->js_func_name . '_submit) {' . "\r\n";
-        $js .= '  if (validator.isError()) {' . "\r\n";
-        $js .= '    validator.displayErrorMessage(true, "' . $this->js_error_header . '", "' . $this->js_error_footer . '");' . "\r\n";
-        $js .= '    return false;' . "\r\n";
-        $js .= '  } else {' . "\r\n";
-        $js .= '    ' . $this->js_func_name . '_submit = true;' . "\r\n";
-        $js .= '    return true;' . "\r\n";
-        $js .= '  }' . "\r\n";
-        $js .= '} else {'         . "\r\n";
-        $js .= '  return false;'  . "\r\n";
-        $js .= '}'                . "\r\n";
-        $js .= "\r\n";
-        $js .= '}'         . "\r\n";
-        $js .= '//-->'     . "\r\n";
-        $js .= '</script>' . "\r\n";
+        $js_all_message = $this->js_all_message ? 'true' : 'false';
 
-        return $js;
+        // Хǡ
+        $validation = file_get_contents(dirname(__FILE__) . '/JsClient/SyL_FormValidater.js');
+        // ƥå᥽å
+        $checker = '';
+        foreach (array_keys($this->elements) as $key) {
+            $checker .= $this->elements[$key]->getJs();
+        }
+
+        // פʬʥȤʤɡ˺
+        $validation = preg_replace('/\/\*[^\/]*\*\//', '', $validation);
+        $validation = preg_replace('/^(\s*)\/\/(.*)$/m', '', $validation);
+        $validation = preg_replace('/^(\s+)(.*)$/m', '$2', $validation);
+
+        return <<< JAVASCRIPT_CODE
+<script type="text/javascript">
+<!--
+{$validation}
+//-->
+</script>
+<script type="text/javascript">
+<!--
+var {$this->js_func_name}_submit = false;
+function {$this->js_func_name}(f)
+{
+  if ({$this->js_func_name}_submit) {
+    return false;
+  }
+  var validator = new SyL_FormValidater(f);
+
+{$checker}
+
+  if (!{$this->js_func_name}_submit) {
+    if (validator.isError()) {
+      validator.displayErrorMessage({$js_all_message}, true, "{$this->js_id}", "{$this->js_error_header}", "{$this->js_error_footer}");
+      return false;
+    } else {
+      {$this->js_func_name}_submit = true;
+      return true;
+    }
+  } else {
+    return false;
+  }
+}
+//-->
+</script>
+JAVASCRIPT_CODE;
     }
 
     /**
@@ -489,14 +536,14 @@ class SyL_Form
     function &getResultArray()
     {
         foreach (array_keys($this->elements) as $name) {
-            $this->results[$name]['label']     = $this->getName($name);
-            $this->results[$name]['html']      = $this->getHtml($name);
-            $this->results[$name]['require']   = $this->isRequire($name);
-            $this->results[$name]['read_only'] = $this->isReadOnly($name);
+            $this->results['elements'][$name]['label']     = $this->getName($name);
+            $this->results['elements'][$name]['html']      = $this->getHtml($name);
+            $this->results['elements'][$name]['require']   = $this->isRequire($name);
+            $this->results['elements'][$name]['read_only'] = $this->isReadOnly($name);
         }
         // եॿ°
-        $this->results['syl_javascript'] = $this->getJavaScript();
-        $this->results['syl_form']       = $this->getAttributes();
+        $this->results['javascript'] = $this->getJs();
+        $this->results['attributes'] = $this->getAttributes();
         return $this->results;
     }
 }
