@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElement.php,v 1.9 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElement.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,25 +44,18 @@ require_once 'SyL_Validation.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElement.php,v 1.9 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElement.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FormElement
 {
     /**
-     * ե̾
+     * եHTMLη
      *
      * @access private
      * @var string
      */
-    var $form_name = '';
-    /**
-     * եɽ̾
-     *
-     * @access private
-     * @var string
-     */
-    var $display_name = '';
+    var $type = '';
     /**
      * եHTML̾
      *
@@ -70,6 +63,13 @@ class SyL_FormElement
      * @var string
      */
     var $name = '';
+    /**
+     * եɽ̾
+     *
+     * @access private
+     * @var string
+     */
+    var $display_name = '';
     /**
      * եǤ
      *
@@ -77,13 +77,6 @@ class SyL_FormElement
      * @var string
      */
     var $value = '';
-    /**
-     * եHTMLη
-     *
-     * @access private
-     * @var string
-     */
-    var $type = null;
     /**
      * եHTMLɲ°
      *
@@ -99,13 +92,6 @@ class SyL_FormElement
      * @var array
      */
     var $options = array();
-    /**
-     * ڥ롼ץ֥
-     *
-     * @access private
-     * @var object
-     */
-    var $validators = null;
     /**
      * ɤ߼ѥե饰
      *
@@ -113,13 +99,6 @@ class SyL_FormElement
      * @var bool
      */
     var $read_only = false;
-    /**
-     * åǽȽ
-     *
-     * @access private
-     * @var bool
-     */
-    var $session = false;
     /**
      * 顼å
      * 顼å''ξϡ顼̵
@@ -128,129 +107,64 @@ class SyL_FormElement
      * @var string
      */
     var $error_message = '';
+    /**
+     * ڥ롼ץ֥
+     *
+     * @access private
+     * @var object
+     */
+    var $validators = null;
+
+    /**
+     * 󥹥ȥ饯
+     *
+     * @access public
+     * @param string եHTMLη
+     * @param string եHTML̾
+     * @param string եɽ̾
+     * @param array ե°
+     */
+    function SyL_FormElement($type, $name, $display_name, $attributes=array())
+    {
+        $this->type         = strtolower($type);
+        $this->name         = $name;
+        $this->display_name = $display_name;
+        $this->attributes   = $attributes;
+    }
 
     /**
      * ̥եǥ֥Ȥμ
      *
      * @access public
      * @param string եǥ
-     * @param string եHTML̾
+     * @param string ե̾
      * @param string եɽ̾
+     * @param mixed ꥯȽ
      * @param array եǤradio, select, checkboxξΤߡ
      * @param mixed եǤ͡checkboxξ󡢤ʳstring
-     * @param string եǤɲ°
+     * @param array եǤɲ°
      */
-    function &create($type, $name, $display_name, $options=array(), $value=null, $attributes=array())
+    function &create($type, $name, $display_name, $value=null, $options=array(), $attributes=array())
     {
-        $type = ucfirst(strtolower($type));
-        $class_name = 'SyL_FormElement' . $type;
-        include_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'FormElement' . DIRECTORY_SEPARATOR . $class_name . '.php';
-        $element_class =& new $class_name($name, $display_name, $options, $value, $attributes);
-        return $element_class;
+        $class_name = 'SyL_FormElement' . ucfirst($type);
+        include_once dirname(__FILE__) . "/FormElement/{$class_name}.php";
+        $element =& new $class_name($type, $name, $display_name, $attributes);
+        $element->setValue($value);
+        $element->setOptions($options);
+        return $element;
     }
 
     /**
-     * ڥ롼ץ֥Ȥ
+     * ɲåץ
      *
-     * @access public
-     * @return object ڥ롼ץ֥
+     * @access protected
+     * @param array եǤradio, select, checkboxξΤߡ
      */
-    function &createValidators()
+    function setOptions($options=array())
     {
-        $validators =& new SyL_Validators();
-        return $validators;
-    }
-
-    /**
-     * ꥯȤͤ
-     *
-     * @access public
-     * @return mixed ꥯѿ
-     */
-    function getParameter()
-    {
-        $value = '';
-        if ($_SERVER['REQUEST_METHOD'] == 'POST') {
-            $value = isset($_POST[$this->name]) ? $_POST[$this->name] : '';
-        } else {
-            $value = isset($_GET[$this->name]) ? $_GET[$this->name] : '';
+        if (is_array($options)) {
+            $this->options = $options;
         }
-
-        return $value;
-    }
-
-    /**
-     * ѿФƺƵŪ˽¹Ԥ
-     *
-     * @access public
-     * @param string ؿ̾
-     * @param mixed ؿΰȤʤѿ
-     */
-    function parametersFilter($func, &$value)
-    {
-        if (is_array($value)) {
-            foreach ($value as $k => $v) {
-                $this->parametersFilter($method, $value[$k]);
-            }
-        } else {
-            $value = call_user_func($func, $value);
-        }
-    }
-
-    /**
-     * եǤɽΤȽ
-     *
-     * @access public
-     * @param bool եǤɽΤߥե饰
-     */
-    function readOnly($read_only)
-    {
-        $this->read_only = $read_only;
-    }
-
-    /**
-     * ե̾򥻥å
-     *
-     * @access public
-     * @param string ե̾
-     */
-    function setFormName($form_name)
-    {
-        $this->form_name = $form_name;
-    }
-
-    /**
-     * ɲ°򥻥å
-     *
-     * @access public
-     * @param string ɲ°
-     */
-    function setAttribute($attribute)
-    {
-        $this->attributes = $attribute;
-    }
-
-    /**
-     * åǽȽ򥻥å
-     *
-     * @access public
-     * @param bool åǽȽ
-     */
-    function setFormSession( $session )
-    {
-        $this->session = $session;
-    }
-
-    /**
-     * ɬܥå¸Ƚ
-     * ڥ롼ץ֥Ȥ򥻥åȤƤ¹Ԥ
-     *
-     * @access public
-     * @return bool true: ɬܥåꡢfalse: ɬܥå̵
-     */
-    function isRequire()
-    {
-        return (is_object($this->validators) ? $this->validators->isRequire() : false);
     }
 
     /**
@@ -264,19 +178,41 @@ class SyL_FormElement
         return $this->name;
     }
 
+    /**
+     * ե̾
+     *
+     * @access public
+     * @return string ե̾
+     */
+    function getType()
+    {
+        return $this->type;
+    }
+
     /**
      * եɽ̾
      *
      * @access public
      * @return string ̾
      */
-    function getDisplayName( $group=false )
+    function getDisplayName()
     {
         return $this->display_name;
     }
 
     /**
-     * ̾
+     * ͤ򥻥åȤ
+     *
+     * @access public
+     * @param mixed 
+     */
+    function setValue($value)
+    {
+        $this->value = $value;
+    }
+
+    /**
+     * ͤ
      *
      * @access public
      * @return string ̾
@@ -297,19 +233,59 @@ class SyL_FormElement
         return $this->error_message;
     }
 
+    /**
+     * °򥻥å
+     *
+     * @access public
+     * @param string °
+     * @param string °̾
+     */
+    function setAttribute($value, $name=null)
+    {
+        if ($name) {
+            $name = strtolower($name);
+            $this->attributes[$name] = $value;
+        } else {
+            $this->attributes[] = $value;
+        }
+    }
+
     /**
      * ¾°
      *
      * @access public
      * @return string ¾°
      */
-    function getAttribute()
+    function getAttributes()
     {
-        $attributes = '';
+        $attributes = array();
         foreach ($this->attributes as $k => $v) {
-            $attributes .= is_numeric($k) ? (' ' . $this->encodeHtml($v) . ' ') : ($k . '="' . $this->encodeHtml($v) . '" ');
+            $attributes[] = is_int($k) ? $this->encode($v) : ($k . '="' . $this->encode($v) . '"');
         }
-        return $attributes;
+        return implode(' ', $attributes);
+    }
+
+    /**
+     * եɽȽե饰򥻥å
+     *
+     * @access public
+     * @param bool եɽȽե饰
+     */
+    function setReadOnly($read_only)
+    {
+        $this->read_only = ($read_only === true);
+    }
+
+    /**
+     * ɬܥå¸Ƚ
+     * ڥ롼ץ֥Ȥ򥻥åȤƤ¹Ԥ
+     *
+     * @access public
+     * @return bool true: ɬܥåꡢfalse: ɬܥå̵
+     */
+    function isRequire()
+    {
+        return is_object($this->validators) ? $this->validators->isRequire() : false;
     }
 
     /**
@@ -347,7 +323,6 @@ class SyL_FormElement
      */
     function getHtmlView()
     {
-        trigger_error("[SyL error] 'getHtmlView' method is not implemented in this class (" . get_class($this) . ")");
     }
 
     /**
@@ -358,7 +333,6 @@ class SyL_FormElement
      */
     function getHtmlTag()
     {
-        trigger_error("[SyL error] 'getHtmlTag' method is not implemented in this class(" . get_class($this) . ")");
     }
 
     /**
@@ -368,19 +342,13 @@ class SyL_FormElement
      * @param bool true: html󥳡ɤԤfalse: html󥳡ɤԤʤ
      * @return string եǤHTML
      */
-    function getHtmlHidden( $name=null, $value=null )
+    function getHtmlHidden($name=null, $value=null)
     {
         if (($name === null) || ($value === null)) {
             $name  = $this->name;
             $value = $this->value;
         }
-        $html_element  = '';
-        $html_element .= '<input type="hidden" ';
-        $html_element .=   'name="'  . $name  . '" ';
-        $html_element .=   'value="' . $this->encodeHtml($value) . '"';
-        $html_element .= '>';
-
-        return $html_element;
+        return '<input type="hidden" name="'  . $name  . '" value="' . $this->encode($value) . '" />';
     }
 
     /**
@@ -390,7 +358,7 @@ class SyL_FormElement
      * @param string HTML󥳡ʸ
      * @return string HTML󥳡ɸʸ
      */
-    function encodeHtml($value)
+    function encode($value)
     {
         return htmlspecialchars($value);
     }
@@ -403,27 +371,29 @@ class SyL_FormElement
      */
     function setValidators(&$validators)
     {
-        $this->validators =& $validators;
+        if (version_compare(PHP_VERSION, '5.0.0', '>=')) {
+            $this->validators = unserialize(serialize($validators));
+        } else {
+            $this->validators = $validators;
+        }
     }
 
     /**
      * ڤ¹Ԥ
      * ڥ롼ץ֥Ȥʤϡtrue
      *
-     * 顼å{name}ʸϡ̾Ѵ
-     *
      * @access public
      * @return bool true: 顼̵false: 顼
      */
     function validate()
     {
-        if (is_object($this->validators)) {
-            if (!$this->validators->execute($this->value)) {
-                $this->error_message = $this->validators->getErrorMessage($this->getDisplayName());
-                return false;
-            } else {
-                return true;
-            }
+        if (!is_object($this->validators)) {
+            return true;
+        }
+
+        if (!$this->validators->execute($this->getValue(), $this->getDisplayName())) {
+            $this->error_message = $this->validators->getErrorMessage();
+            return false;
         } else {
             return true;
         }
@@ -435,14 +405,14 @@ class SyL_FormElement
      * @access public
      * @return string JavaScriptϥå
      */
-    function getJavaScript()
+    function getJs()
     {
         if (is_object($this->validators)) {
             $js  = '';
-            $js .= 'var error_flag = false;' . "\r\n";
-            $js .= 'var element_name = "' . $this->getName() . '";' . "\r\n";
-            $js .= $this->validators->getJavaScript($this->getDisplayName(), $this->options);
-            $js .= "\r\n";
+            $js .= 'var error_flag = false;' . "\n";
+            $js .= 'var element_name = "' . $this->getName() . '";' . "\n";
+            $js .= $this->validators->getJs($this->getDisplayName(), $this->options);
+            $js .= "\n";
             return $js;
         } else {
             return '';
