@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.10 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.11 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,11 +52,18 @@ if (!defined('SYL_ENCODE_INTERNAL')) {
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.10 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.11 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Mail
 {
+    /**
+     * ᡼ץѥƥ
+     * 
+     * @access protected
+     * @var array
+     */
+    var $mail_property = array();
     /**
      * ᡼إå
      * 
@@ -65,42 +72,18 @@ class SyL_Mail
      */
     var $headers = array();
     /**
-     * ᡼إåʤ¾
+     * ʸ
+     *
+     * [body]              - ʸ
+     * [name]              - źեե̾
+     * [file]              - źեե
+     * [type]              - Content-Type
+     * [transfer_encoding] - Content-Transfer-Encoding
      * 
      * @access protected
      * @var array
      */
-    var $headers_etc = array();
-    /**
-     * ᡼ʸ
-     * 
-     * @access protected
-     * @var string
-     */
-    var $body = '';
-  
-    /**
-     * źեե̾
-     * 
-     * @access protected
-     * @var array
-     */
-    var $f_name = array();
-    /**
-     * źեե
-     * 
-     * @access protected
-     * @var array
-     */
-    var $f_contents = array();
-    /**
-     * Х
-     * 
-     * @access protected
-     * @var string
-     */
-    var $f_boundary = '';
-  
+    var $attachments = array();
     /**
      * X-Mailerإå
      * 
@@ -108,11 +91,25 @@ class SyL_Mail
      * @var string
      */
     var $x_mailer = 'SyL Mail';
-
-/*
-  var $htmail;
-*/
-
+    /**
+     * 󥳡
+     *
+     * Base64Τб
+     * 
+     * B: base64
+     * Q: Quoted-Printable
+     * 
+     * @access protected
+     * @var string
+     */
+    var $transfer_encoding = 'B';
+    /**
+     * 
+     * 
+     * @access protected
+     * @var string
+     */
+    var $eol = "\r\n";
     /**
      * ᡼ƤΥ󥳡
      * 
@@ -143,68 +140,51 @@ class SyL_Mail
     function SyL_Mail()
     {
         // ʲǥեȥإå
-        $this->headers_etc['Mime-version'] = '1.0';
-        $this->headers_etc['Content-type'] = 'text/plain; charset="iso-2022-jp"';
-        $this->headers_etc['Content-transfer-encoding'] = '7bit';
-        if ($this->x_mailer != '') {
-            $this->headers_etc['X-Mailer'] = $this->x_mailer;
+        $this->headers['MIME-Version'] = '1.0';
+        if ($this->x_mailer) {
+            $this->headers['X-Mailer'] = $this->x_mailer;
         }
-
         $this->init();
     }
 
     /**
      * SyL_Mail饹Υ󥹥󥹼
      *
-     * Mail֥Ⱥ
-     *
-     * ˡ
-     *   $mail =& SyL_Mail::getInstance();
-     *
      * @access public
+     * @param string ᡼
      */
     function &getObject($type='Default')
     {
-        $class_name = 'SyL_Mail' . ucfirst($type);
+        $types = explode(':', $type, 2);
+        if (!isset($types[1])) {
+            $types[1] = null;
+        }
+        $class_name = 'SyL_Mail' . ucfirst($types[0]);
         include_once dirname(__FILE__) . '/Mail/' . $class_name . '.php';
-        $obj = new $class_name();
-        return $obj;
+        $mail = new $class_name($types[1]);
+        return $mail;
     }
 
-//  function setHtml( $flag=true )
-//  {
-//    if ($flag) {
-//      $this->headers['Content-Type'] =  'multipart/alternative; boundary=--wbmd-multipart--';
-//      $this->htmail = true;
-//    } else {
-//      $this->headers['Content-type'] = 'text/plain; charset="ISO-2022-JP"';
-//      $this->htmail = false;
-//    }
-//  }
-
     /**
      * ɥ쥹򥻥å
      *
-     * ڡڤǡ̾⥻åȤ뤳Ȥǽ
-     * ˥åʸ: hoge@example.com ۥ
-     *     ʸ:   ۥ <hoge@example.com>
-     * 
      * @access public
      * @param string ɥ쥹
+     * @param string ̾
      */
     function setFrom($from, $name='')
     {
-        $this->headers['From'] = $this->convertEncodingAddress($from, $name, true);
+        $this->mail_property['MAIL_FROM'] = $from;
+        $this->mail_property['Reply-To']  = $from;
+        $this->headers['From'] = $this->convertEncodingAddress($from, $name);
     }
 
     /**
      * 襢ɥ쥹򥻥å
-     * ڡڤǡ̾⥻åȤ뤳Ȥǽ
-     * ˥åʸ: hoge@hogehoge.com ۥ
-     *     ʸ:   ۥ <hoge@hogehoge.com>
      * 
      * @access public
-     * @param string 襢ɥ쥹
+     * @param mixed 襢ɥ쥹
+     * @param string ̾
      */
     function addTo($to, $name='')
     {
@@ -213,18 +193,17 @@ class SyL_Mail
                 $this->addTo($tmp, $name);
             }
         } else {
+            $this->mail_property['RCPT_TO'][] = $to;
             $this->headers['To'][] = $this->convertEncodingAddress($to, $name);
         }
     }
 
     /**
      * 襢ɥ쥹(CC)򥻥å
-     * ڡڤǡ̾⥻åȤ뤳Ȥǽ
-     * ˥åʸ: hoge@hogehoge.com ۥ
-     *     ʸ:   ۥ <hoge@hogehoge.com>
      * 
      * @access public
-     * @param string 襢ɥ쥹(CC)
+     * @param mixed 襢ɥ쥹(CC)
+     * @param string ̾(CC)
      */
     function addCc($cc, $name='')
     {
@@ -233,18 +212,17 @@ class SyL_Mail
                 $this->addCc($tmp, $name);
             }
         } else {
+            $this->mail_property['RCPT_TO'][] = $cc;
             $this->headers['Cc'][] = $this->convertEncodingAddress($cc, $name);
         }
     }
 
     /**
      * 襢ɥ쥹(BCC)򥻥å
-     * ڡڤǡ̾⥻åȤ뤳Ȥǽ
-     * ˥åʸ: hoge@hogehoge.com ۥ
-     *     ʸ:   ۥ <hoge@hogehoge.com>
      * 
      * @access public
-     * @param string 襢ɥ쥹(BCC)
+     * @param mixed 襢ɥ쥹(BCC)
+     * @param string ̾(BCC)
      */
     function addBcc($bcc, $name='')
     {
@@ -253,6 +231,7 @@ class SyL_Mail
                 $this->addBcc($tmp, $name);
             }
         } else {
+            $this->mail_property['RCPT_TO'][] = $bcc;
             $this->headers['Bcc'][] = $this->convertEncodingAddress($bcc, $name);
         }
     }
@@ -276,29 +255,11 @@ class SyL_Mail
      */
     function setBody($body)
     {
-        $this->body = $this->convertEncoding($body);
-    }
-
-    /**
-     * ѥ᡼Υ󥳡ɤ򥻥å
-     *
-     * @access public
-     * @param string ѥ᡼Υ󥳡
-     */
-    function setParameterEncode($encode)
-    {
-        $this->internal_encode = $encode;
-    }
-
-    /**
-     * ᡼ƤΥ󥳡ɤ򥻥å
-     *
-     * @access public
-     * @param string ᡼ƤΥ󥳡
-     */
-    function setMailEncode($encode)
-    {
-        $this->mail_encode = $encode;
+        $this->attachments[] = array(
+          'body'              => $this->convertEncoding($body),
+          'type'              => 'text/plain; charset="' . $this->mail_encode . '"',
+          'transfer_encoding' => '7bit'
+        );
     }
 
     /**
@@ -311,11 +272,8 @@ class SyL_Mail
      */
     function convertEncoding($parameter, $mime_encode=false)
     {
-        $parameter = mb_convert_encoding($parameter, $this->mail_encode, $this->internal_encode);
-        if ($mime_encode) {
-            $parameter = mb_encode_mimeheader($parameter, $this->mail_encode);
-        }
-        return $parameter;
+        $parameter = mb_convert_encoding(mb_convert_kana($parameter, 'KV', $this->internal_encode), $this->mail_encode, $this->internal_encode);
+        return ($mime_encode) ? mb_encode_mimeheader($parameter, $this->mail_encode, $this->transfer_encoding) : $parameter;
     }
 
     /**
@@ -324,28 +282,14 @@ class SyL_Mail
      * @access public
      * @param string ᡼륢ɥ쥹
      * @param string ᡼륢ɥ쥹̾
-     * @param bool Fromե饰
      * @return string 󥳡ǥ󥰤Υ᡼륢ɥ쥹
      */
-    function convertEncodingAddress($address, $name='', $from=false)
+    function convertEncodingAddress($address, $name='')
     {
-        $address = explode(' ', trim($address), 2);
-
-        if (($name == '') && isset($address[1])) {
-            $name = $address[1];
-        }
-
-        if ($from) {
-            $this->headers['MAIL_FROM'] = $address[0];
-            $this->headers_etc['Reply-To'] = $address[0];
+        if ($name) {
+            return '"' . $this->convertEncoding($name, true) . '" <' . $address . '>';
         } else {
-            $this->headers['RCPT_TO'][] = $address[0];
-        }
-
-        if (isset($address[1]) && (trim($address[1]) != '')) {
-            return '"' . $this->convertEncoding($name, true) . '" <' . $address[0] . '>';
-        } else {
-            return '"' . $address[0] . '" <' . $address[0] . '>';
+            return $address;
         }
     }
 
@@ -358,7 +302,7 @@ class SyL_Mail
      */
     function setHeader($key, $value)
     {
-        $this->headers_etc[$key] = $value;
+        $this->headers[$key] = $value;
     }
 
     /**
@@ -369,12 +313,7 @@ class SyL_Mail
      */
     function setHeaders($headers)
     {
-        $this->headers_etc = array_merge($this->headers_etc, $headers);
-/*
-    foreach ($headers as $key => $value) {
-      $this->setHeader($key, $value);
-    }
-*/
+        $this->headers += $headers;
     }
 
     /**
@@ -383,18 +322,29 @@ class SyL_Mail
      * @access public
      * @param string եѥʥե̾ޤǴޤ
      */
-    function setFile($path)
+    function addFile($path, $contents_type='application/octet-stream')
     {
-        // źեե
-        $f_contents = file_get_contents($path);
         // ե̾
-        $f_name = basename($path);
-        // źեեѥإåå
-        $this->headers_etc['Content-type'] = 'multipart/mixed; boundary=' . $this->f_boundary . ';';
-        $this->headers_etc['Content-transfer-encoding'] = 'Base64';
+        $name = basename($path);
+        // źեե
+        $contents = file_get_contents($path);
+        switch ($this->transfer_encoding) {
+        case 'B':
+            $contents = chunk_split(base64_encode($contents));
+            $transfer_encoding = 'Base64';
+            break;
+        default:
+            trigger_error("[SyL error] Content-Transfer-Encoding not supported ({$this->transfer_encoding})", E_USER_ERROR);
+            break;
+        }
+        
         // źեե󥻥å
-        $this->f_name[]     = $this->convertEncoding($f_name, true);
-        $this->f_contents[] = chunk_split(base64_encode($f_contents));
+        $this->attachments[] = array(
+          'name'              => $this->convertEncoding($name, true),
+          'file'              => $contents,
+          'type'              => $contents_type,
+          'transfer_encoding' => $transfer_encoding
+        );
     }
 
     /**
@@ -402,15 +352,14 @@ class SyL_Mail
      *
      * @access public
      * @param array ᡼°
-     * @param bool ե饰
      */
     function init($attributes=array())
     {
         $attributes = array_change_key_case($attributes, CASE_LOWER);
 
         // ǡ
-        $this->headers['MAIL_FROM'] = '';
-        $this->headers['RCPT_TO']   = array();
+        $this->mail_property['MAIL_FROM'] = '';
+        $this->mail_property['RCPT_TO']   = array();
 
         // 긵
         $this->headers['From'] = '';
@@ -442,66 +391,69 @@ class SyL_Mail
         if (isset($attributes['body'])) {
             $this->setBody($attributes['body']);
         }
-
-        $this->f_name     = array();
-        $this->f_contents = array();
-        $this->f_boundary = "-=-=-=-=-=-=-=-=-Boundary_" . uniqid("b");
- 
-//    $this->htmail           = false;
-  }
+    }
 
     /**
      * ᡼إåޤʸ
      *
      * @access public
-     * @param string ʸ
      * @return string ᡼إåޤʸ
      */
-    function getHeaderMessage($body)
+    function createSendMessage()
     {
         // ᡼إå
         $data  = '';
-        $data .= 'Subject: ' . $this->headers['Subject'] . "\r\n";
-        $data .= 'From: '    . $this->headers['From']    . "\r\n";
-        $data .= 'To: '      . implode(', ', $this->headers['To']) . "\r\n";
-        if (count($this->headers['Cc']) > 0) {
-            $data .= 'Cc: ' . implode(', ', $this->headers['Cc'])  . "\r\n";
-        }
-        if (count($this->headers['Bcc'] ) > 0) {
-            $data .= 'Bcc: ' . implode(', ', $headers['Bcc']) . "\r\n";
-        }
-        foreach ($this->headers_etc as $key => $value) {
-            $data .= $key . ': ' . $value . "\r\n";
-        }
-        $data .= "\r\n";
-
-        // ᡼ʸ
-        if (count($this->f_name) > 0) {
-            // -------------------------------
-            // źեեդƥȥ᡼
-            // -------------------------------
-            $data .= '--' . $this->f_boundary . "\r\n";
-            $data .= 'Content-Type: text/plain; charset="iso-2022-jp"' . "\r\n";
-            $data .= "\r\n";
-            $data .= $body . "\r\n";
-            for ($i=0; $i<count($this->f_name); $i++) {
-                $data .= '--' . $this->f_boundary . "\r\n";
-                $data .= 'Content-Type: application/octet-stream; name="' . $this->f_name[$i] . '"' . "\r\n";
-                $data .= 'Content-Disposition: attachment; filename="'    . $this->f_name[$i] . '"' . "\r\n";
-                $data .= 'Content-Transfer-Encoding: base64' . "\r\n";
-                $data .= "\r\n";
-                $data .= $this->f_contents[$i] . "\r\n";
-                $data .= "\r\n";
+        // Х
+        $boundary = '--' . md5(uniqid(rand()));
+        // Ƽإå򥻥å
+        foreach ($this->headers as $name => $value) {
+            if (is_array($value)) {
+                $value = implode(', ', $value);
             }
-            $data .= '--' . $this->f_boundary . "--\r\n";
-        } else {
-            // ̾Υƥȥ᡼
-            $data .= $body . "\r\n";
+            $data .= "{$name}: {$value}" . $this->eol;
+        }
+        switch (count($this->attachments)) {
+        case 0:
+            break;
+        case 1:
+            $data .= $this->getAttachmentData($this->attachments[0]);
+            break;
+        default:
+            $data .= "Content-Type: multipart/mixed; boundary=\"$boundary\"" . $this->eol;
+            $data .= $this->eol;
+            for ($i=0; $i<count($this->attachments); $i++) {
+                $data .= '--' . $boundary . $this->eol;
+                $data .= $this->getAttachmentData($this->attachments[$i]);
+            }
+            $data .= '--' . $boundary . "--" . $this->eol;
         }
-
         return $data;
     }
 
+    /**
+     * ʸźǡ
+     *
+     * @access public
+     * @param array ǡ
+     * @return string ʸźǡ
+     */
+    function getAttachmentData(&$attachment)
+    {
+        $data  = '';
+        $data .= "Content-Type: {$attachment['type']}" . $this->eol;
+        $data .= "Content-Transfer-Encoding: {$attachment['transfer_encoding']}" . $this->eol;
+        if (isset($attachment['body'])) {
+            // ƥ
+            $data .= $this->eol;
+            $data .= $attachment['body'] . $this->eol;
+        } else {
+            // ź
+            $data .= "Content-Disposition: attachment; filename=\"{$attachment['name']}\"" . $this->eol;
+            $data .= $this->eol;
+            $data .= $attachment['file'] . $this->eol;
+        }
+        return $data;
+    }
 
     /**
      * ᡼¹
@@ -513,16 +465,6 @@ class SyL_Mail
     {
     }
 
-    /**
-     * ᡼
-     *
-     * @access public
-     * @return OK: true, NG: false
-     */
-    function quit()
-    {
-    }
-
     /**
      * 顼åȽ
      *
