@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.1 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.1 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidators extends SyL_Validation
@@ -75,7 +75,6 @@ class SyL_ValidationValidators extends SyL_Validation
     function add(&$validator)
     {
         if (version_compare(PHP_VERSION, '5.0.0', '>=')) {
-            // cloneɤPHP4顼ȤʤΤǡserializeǲ
             $this->validators[] = unserialize(serialize($validator));
         } else {
             $this->validators[] = $validator;
@@ -125,11 +124,11 @@ class SyL_ValidationValidators extends SyL_Validation
      * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJavaScript($display_name, $parts)
+    function getJs($display_name, $options=array())
     {
         $js = '';
         foreach (array_keys($this->validators) as $key) {
-            $js .= $this->validators[$key]->getJavaScript($display_name, $parts);
+            $js .= $this->validators[$key]->getJs($display_name, $options);
         }
         return $js;
     }
