@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorRequire.php,v 1.1 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorRequire.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -45,7 +45,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorRequire.php,v 1.1 2007/03/31 08:45:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorRequire.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidatorRequire extends SyL_ValidationValidator
@@ -57,8 +57,7 @@ class SyL_ValidationValidatorRequire extends SyL_ValidationValidator
      * @var array
      */
     var $parameters = array(
-      'format' => null,
-      'trim'   => null
+      'trim' => false
     );
 
     /**
@@ -70,14 +69,10 @@ class SyL_ValidationValidatorRequire extends SyL_ValidationValidator
      */
     function validate($value)
     {
-        if ($this->parameters['format'] !== null) {
-            return preg_match($this->parameters['format'], $value);
-        } else {
-            if ($this->parameters['trim'] === true) {
-                $value = trim($value);
-            }
-            return (($value !== null) && ($value !== ''));
+        if ($this->parameters['trim'] === true) {
+            $value = trim($value);
         }
+        return (($value !== null) && ($value !== ''));
     }
 
     /**
@@ -87,13 +82,17 @@ class SyL_ValidationValidatorRequire extends SyL_ValidationValidator
      * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJavaScriptCode($parts)
+    function getJsCode($options=array())
     {
-        $format = ($this->parameters['format'] !== null) ? $this->parameters['format'] : '""';
+        $options = array();
+        $options[] = "'trim': " . ($this->parameters['trim'] ? 'true' : 'false');
+        $options[] = "'min_valids': '{$this->min_valids}'";
+        $options[] = "'max_valids': '{$this->max_valids}'";
+
         $js  = '';
-        $js .= 'if (!error_flag && !validator.isRequire(element_name, "' . $this->getErrorMessage() . '", ' . $format . ')) {' . "\r\n";
-        $js .= '  error_flag = true;' . "\r\n";
-        $js .= '}' . "\r\n";
+        $js .= 'if (!error_flag && !validator.isRequire(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '})) {' . "\n";
+        $js .= '  error_flag = true;' . "\n";
+        $js .= '}' . "\n";
         return $js;
     }
 }
